stafftools.Staff
================

.. abjad-lineage:: abjad.tools.stafftools.Staff.Staff.Staff

.. autoclass:: abjad.tools.stafftools.Staff.Staff.Staff
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.contents_duration
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.descendants
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.leaves
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.lineage
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.music
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.override
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.parent
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.parentage
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.prolation
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.set
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.spanners
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.start_offset
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.storage_format
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.timespan
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.context_name
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.is_parallel
   :noindex:

.. autoattribute:: abjad.tools.stafftools.Staff.Staff.Staff.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.append
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.extend
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.index
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.insert
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.pop
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__add__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__contains__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__delitem__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__eq__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__ge__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__getitem__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__gt__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__iadd__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__imul__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__le__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__len__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__lt__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__mul__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__ne__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__radd__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__repr__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__rmul__
   :noindex:

.. automethod:: abjad.tools.stafftools.Staff.Staff.Staff.__setitem__
   :noindex:
